
from .resnet import ResNet, ResNetV1d, resnet18,resnet50
from .shufflenet_v1 import ShuffleNetV1, shufflenetv1


__all__ = [ 'ResNet', 'ResNetV1d',
    'ShuffleNetV1','resnet50','resnet18','shufflenetv1'
]
